#include "rheolef.h"
using namespace rheolef;
using namespace std;
int main(int argc, char** argv) {
  environment rheolef (argc, argv);
  field uh;
  din >> uh;
  const space& Xh = uh.get_space();
  string grad_approx = "P" + itos(Xh.degree()-1) + "d";
  string valued = (uh.size() == 3) ? "vector" : "scalar";
  space Lh  (uh.get_geo(), grad_approx, valued);
  field curl_uh = interpolate (Lh, curl(uh));
  dout << catchmark("w") << curl_uh;
}
